@@ -13,29 +13,29 @@ def check(message: str) -> bool:
 
 
 def sanitize(message: str) -> str:
-    message = message.removeprefix("```")
-    message = message.removesuffix("```")
+    message = message.replace("```", "")
+    message = re.sub(r"\n\n\n+", "\n\n", message)
     message = message.strip()
     lines: Sequence[str] = [sanitize_line(line) for line in message.splitlines()]
     return "\n".join(lines)
 
 
-def sanitize_line(message: str) -> str:
-    matches: Optional[re.Match[str]] = PATTERN.fullmatch(message)
+def sanitize_line(line: str) -> str:
+    matches: Optional[re.Match[str]] = PATTERN.fullmatch(line)
     if matches is None:
-        return message
+        return line
     type_: str = matches.group("type")
     scope: Optional[str] = matches.group("scope")
     breaking: Optional[str] = matches.group("breaking")
     description: str = matches.group("description")
     type_ = type_.strip()
-    message = type_
+    line = type_
     if scope is not None:
         scope = scope.strip().lower()
-        message += f"({scope})"
+        line += f"({scope})"
     if breaking is not None:
-        message += "!"
+        line += "!"
     description = description.strip()
     description = description[0].lower() + description[1:]
-    message += f": {description}"
-    return message
+    line += f": {description}"
+    return line
